package com.ruoyi.mall.service.impl;

import com.ruoyi.mall.domain.MallIntroduceClass;
import com.ruoyi.mall.mapper.MallIntroduceClassMapper;
import com.ruoyi.mall.service.IMallIntroduceClassService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 学校介绍类别Service业务层处理
 *
 * @author Lsm
 * @date 2023-10-18
 */
@Service
public class MallIntroduceClassServiceImpl implements IMallIntroduceClassService
{
    @Autowired
    private MallIntroduceClassMapper mallIntroduceClassMapper;

    /**
     * 查询学校介绍类别
     *
     * @param introduceClassId 学校介绍类别主键
     * @return 学校介绍类别
     */
    @Override
    public MallIntroduceClass selectMallIntroduceClassByIntroduceClassId(Long introduceClassId)
    {
        return mallIntroduceClassMapper.selectMallIntroduceClassByIntroduceClassId(introduceClassId);
    }

    /**
     * 查询学校介绍类别列表
     *
     * @param mallIntroduceClass 学校介绍类别
     * @return 学校介绍类别
     */
    @Override
    public List<MallIntroduceClass> selectMallIntroduceClassList(MallIntroduceClass mallIntroduceClass)
    {
        return mallIntroduceClassMapper.selectMallIntroduceClassList(mallIntroduceClass);
    }

    /**
     * 新增学校介绍类别
     *
     * @param mallIntroduceClass 学校介绍类别
     * @return 结果
     */
    @Override
    public int insertMallIntroduceClass(MallIntroduceClass mallIntroduceClass)
    {
        return mallIntroduceClassMapper.insertMallIntroduceClass(mallIntroduceClass);
    }

    /**
     * 修改学校介绍类别
     *
     * @param mallIntroduceClass 学校介绍类别
     * @return 结果
     */
    @Override
    public int updateMallIntroduceClass(MallIntroduceClass mallIntroduceClass)
    {
        return mallIntroduceClassMapper.updateMallIntroduceClass(mallIntroduceClass);
    }

    /**
     * 批量删除学校介绍类别
     *
     * @param introduceClassIds 需要删除的学校介绍类别主键
     * @return 结果
     */
    @Override
    public int deleteMallIntroduceClassByIntroduceClassIds(Long[] introduceClassIds)
    {
        return mallIntroduceClassMapper.deleteMallIntroduceClassByIntroduceClassIds(introduceClassIds);
    }

    /**
     * 删除学校介绍类别信息
     *
     * @param introduceClassId 学校介绍类别主键
     * @return 结果
     */
    @Override
    public int deleteMallIntroduceClassByIntroduceClassId(Long introduceClassId)
    {
        return mallIntroduceClassMapper.deleteMallIntroduceClassByIntroduceClassId(introduceClassId);
    }
}
